syntax = "proto3";
package ubii.dataStructure;

import "topicData/topicDataRecord/dataStructure/buttonEventType.proto";

message MouseEvent {
    ubii.dataStructure.ButtonEventType type = 1;
    int32 button = 2;
}