"""
@generated by codestare-proto-plus.  Do not edit manually!

Note:
    __init__.py files for packages are autogenerated, and import all messages from submodules to keep import names consistent with the directory structure of the ``.proto`` source files.
"""
from .topicSubscription_pb_plus import (
    TopicSubscription,
)


__all__ = (
    "TopicSubscription",
)