"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    DOUBLE,
    Field,
    module,
)

from proto.message import (
    Message,
)


__protobuf__ = module(
    package="ubii.proto.v1",
    manifest={
        "Matrix3x2",
    }
)


class Matrix3x2(Message):
    """Generated from ubii/proto/v1/dataStructure/matrix3x2.proto

    Attributes:
        m00 (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.DOUBLE`

        m01 (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.DOUBLE`

        m10 (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.DOUBLE`

        m11 (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.DOUBLE`

        m20 (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.DOUBLE`

        m21 (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.DOUBLE`

    """

    m00 = Field(
        DOUBLE,
        number=1,
    )
    m01 = Field(
        DOUBLE,
        number=2,
    )
    m10 = Field(
        DOUBLE,
        number=3,
    )
    m11 = Field(
        DOUBLE,
        number=4,
    )
    m20 = Field(
        DOUBLE,
        number=5,
    )
    m21 = Field(
        DOUBLE,
        number=6,
    )

