syntax = "proto3";
package ubii.services;


message Service {
    string topic = 1;
    string request_message_format = 2;
    string response_message_format = 3;
    repeated string tags = 4;
    string description = 5;
}

message ServiceList {
    repeated ubii.services.Service elements = 1;
}