"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    Field,
    INT32,
    RepeatedField,
    STRING,
    module,
)

from proto.message import (
    Message,
)

from ubii.proto.v1.topicData.topicDataRecord_pb_plus import (
    TopicDataRecord,
)


__protobuf__ = module(
    package="ubii.proto.v1",
    manifest={
        "LockstepProcessingRequest",
        "LockstepProcessingReply",
    }
)


class LockstepProcessingRequest(Message):
    """Generated from ubii/proto/v1/processing/lockstepProcessing.proto

    Attributes:
        processing_module_ids (proto.fields.RepeatedField):
            :obj:`~proto.fields.RepeatedField` of type :obj:`~proto.STRING`

        records (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of
            type
            :obj:`~ubii.proto.v1.topicData.topicDataRecord_pb_plus.TopicDataRecord`

        delta_time_ms (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.INT32`

    """

    processing_module_ids = RepeatedField(
        STRING,
        number=1,
    )
    records = RepeatedField(
        TopicDataRecord,
        number=2,
    )
    delta_time_ms = Field(
        INT32,
        number=3,
    )


class LockstepProcessingReply(Message):
    """Generated from ubii/proto/v1/processing/lockstepProcessing.proto

    Attributes:
        processing_module_ids (proto.fields.RepeatedField):
            :obj:`~proto.fields.RepeatedField` of type :obj:`~proto.STRING`

        records (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of
            type
            :obj:`~ubii.proto.v1.topicData.topicDataRecord_pb_plus.TopicDataRecord`

    """

    processing_module_ids = RepeatedField(
        STRING,
        number=1,
    )
    records = RepeatedField(
        TopicDataRecord,
        number=2,
    )

