syntax = "proto3";
package ubii.dataStructure;

import "topicData/topicDataRecord/dataStructure/pose3d.proto";
import "topicData/topicDataRecord/dataStructure/vector3.proto";

message Object3D {
    string id = 1;
    ubii.dataStructure.Pose3D pose = 2;
    ubii.dataStructure.Vector3 size = 3;
    string user_data_json = 4;
}

message Object3DList {
    repeated ubii.dataStructure.Object3D elements = 1;
}

