"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    Field,
    INT32,
    module,
)

from proto.message import (
    Message,
)

from ubii.proto.v1.dataStructure.buttonEventType_pb_plus import (
    ButtonEventType,
)


__protobuf__ = module(
    package="ubii.proto.v1",
    manifest={
        "MouseEvent",
    }
)


class MouseEvent(Message):
    """Generated from ubii/proto/v1/dataStructure/mouseEvent.proto

    Attributes:
        type (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.buttonEventType_pb_plus.ButtonEventType`

        button (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.INT32`

    """

    type = Field(
        ButtonEventType,
        number=1,
    )
    button = Field(
        INT32,
        number=2,
    )

