"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    Field,
    INT32,
    INT64,
    module,
)

from proto.message import (
    Message,
)


__protobuf__ = module(
    package="ubii.proto.v1",
    manifest={
        "Timestamp",
    }
)


class Timestamp(Message):
    """Generated from ubii/proto/v1/topicData/timestamp.proto

    Attributes:
        seconds (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.INT64`

        nanos (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.INT32`

        millis (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.INT64`

    """

    seconds = Field(
        INT64,
        number=1,
    )
    nanos = Field(
        INT32,
        number=2,
    )
    millis = Field(
        INT64,
        number=3,
    )

