"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    Enum,
    module,
)


__protobuf__ = module(
    package="ubii.proto.v1",
    manifest={
        "ButtonEventType",
    }
)


class ButtonEventType(Enum):
    UP = 0
    DOWN = 1
