syntax = "proto3";
package ubii.processing;

import "topicData/topicDataRecord/topicDataRecord.proto";

message LockstepProcessingRequest {
    repeated string processing_module_ids = 1;
    repeated ubii.topicData.TopicDataRecord records = 2;
    int32 delta_time_ms = 3;
}

message LockstepProcessingReply {
    repeated string processing_module_ids = 1;
    repeated ubii.topicData.TopicDataRecord records = 2;
}