"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    Field,
    module,
)

from proto.message import (
    Message,
)

from ubii.proto.v1.dataStructure.quaternion_pb_plus import (
    Quaternion,
)

from ubii.proto.v1.dataStructure.vector3_pb_plus import (
    Vector3,
)


__protobuf__ = module(
    package="ubii.proto.v1",
    manifest={
        "Pose3D",
    }
)


class Pose3D(Message):
    """Generated from ubii/proto/v1/dataStructure/pose3d.proto

    Attributes:
        position (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.vector3_pb_plus.Vector3`

        quaternion (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.quaternion_pb_plus.Quaternion`

        euler (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.vector3_pb_plus.Vector3`

    """

    position = Field(
        Vector3,
        number=1,
    )
    quaternion = Field(
        Quaternion,
        number=2,
        oneof='orientation',
    )
    euler = Field(
        Vector3,
        number=3,
        oneof='orientation',
    )

