"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    BOOL,
    DOUBLE,
    FLOAT,
    INT32,
    RepeatedField,
    STRING,
    module,
)

from proto.message import (
    Message,
)


__protobuf__ = module(
    package="ubii.proto.v1",
    manifest={
        "StringList",
        "DoubleList",
        "FloatList",
        "BoolList",
        "Int32List",
    }
)


class StringList(Message):
    """Generated from ubii/proto/v1/dataStructure/lists.proto

    Attributes:
        elements (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of
            type :obj:`~proto.STRING`

    """

    elements = RepeatedField(
        STRING,
        number=1,
    )


class DoubleList(Message):
    """Generated from ubii/proto/v1/dataStructure/lists.proto

    Attributes:
        elements (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of
            type :obj:`~proto.DOUBLE`

    """

    elements = RepeatedField(
        DOUBLE,
        number=1,
    )


class FloatList(Message):
    """Generated from ubii/proto/v1/dataStructure/lists.proto

    Attributes:
        elements (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of
            type :obj:`~proto.FLOAT`

    """

    elements = RepeatedField(
        FLOAT,
        number=1,
    )


class BoolList(Message):
    """Generated from ubii/proto/v1/dataStructure/lists.proto

    Attributes:
        elements (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of
            type :obj:`~proto.BOOL`

    """

    elements = RepeatedField(
        BOOL,
        number=1,
    )


class Int32List(Message):
    """Generated from ubii/proto/v1/dataStructure/lists.proto

    Attributes:
        elements (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of
            type :obj:`~proto.INT32`

    """

    elements = RepeatedField(
        INT32,
        number=1,
    )

