"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    Field,
    RepeatedField,
    STRING,
    module,
)

from proto.message import (
    Message,
)


__protobuf__ = module(
    package="ubii.proto.v1",
    manifest={
        "TopicSubscription",
    }
)


class TopicSubscription(Message):
    """Generated from ubii/proto/v1/services/request/topicSubscription.proto

    Attributes:
        client_id (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.STRING`

        subscribe_topics (proto.fields.RepeatedField):
            :obj:`~proto.fields.RepeatedField` of type :obj:`~proto.STRING`

        unsubscribe_topics (proto.fields.RepeatedField):
            :obj:`~proto.fields.RepeatedField` of type :obj:`~proto.STRING`

        subscribe_topic_regexp (proto.fields.RepeatedField):
            :obj:`~proto.fields.RepeatedField` of type :obj:`~proto.STRING`

        unsubscribe_topic_regexp (proto.fields.RepeatedField):
            :obj:`~proto.fields.RepeatedField` of type :obj:`~proto.STRING`

    """

    client_id = Field(
        STRING,
        number=1,
    )
    subscribe_topics = RepeatedField(
        STRING,
        number=2,
    )
    unsubscribe_topics = RepeatedField(
        STRING,
        number=3,
    )
    subscribe_topic_regexp = RepeatedField(
        STRING,
        number=4,
    )
    unsubscribe_topic_regexp = RepeatedField(
        STRING,
        number=5,
    )

