"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    Field,
    RepeatedField,
    STRING,
    module,
)

from proto.message import (
    Message,
)


__protobuf__ = module(
    package="ubii.proto.v1",
    manifest={
        "TopicDemux",
        "TopicDemuxList",
    }
)


class TopicDemux(Message):
    """Generated from ubii/proto/v1/devices/topicDemux.proto

    Attributes:
        id (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.STRING`

        name (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.STRING`

        data_type (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.STRING`

        output_topic_format (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.STRING`

    """

    id = Field(
        STRING,
        number=1,
    )
    name = Field(
        STRING,
        number=2,
    )
    data_type = Field(
        STRING,
        number=3,
    )
    output_topic_format = Field(
        STRING,
        number=4,
    )


class TopicDemuxList(Message):
    """Generated from ubii/proto/v1/devices/topicDemux.proto

    Attributes:
        elements (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of
            type :obj:`~.TopicDemux`

    """

    elements = RepeatedField(
        TopicDemux,
        number=1,
    )

