"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    DOUBLE,
    Field,
    RepeatedField,
    module,
)

from proto.message import (
    Message,
)


__protobuf__ = module(
    package="ubii.proto.v1",
    manifest={
        "Vector8",
        "Vector8List",
    }
)


class Vector8(Message):
    """Generated from ubii/proto/v1/dataStructure/vector8.proto

    Attributes:
        v0 (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.DOUBLE`

        v1 (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.DOUBLE`

        v2 (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.DOUBLE`

        v3 (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.DOUBLE`

        v4 (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.DOUBLE`

        v5 (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.DOUBLE`

        v6 (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.DOUBLE`

        v7 (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.DOUBLE`

    """

    v0 = Field(
        DOUBLE,
        number=1,
    )
    v1 = Field(
        DOUBLE,
        number=2,
    )
    v2 = Field(
        DOUBLE,
        number=3,
    )
    v3 = Field(
        DOUBLE,
        number=4,
    )
    v4 = Field(
        DOUBLE,
        number=5,
    )
    v5 = Field(
        DOUBLE,
        number=6,
    )
    v6 = Field(
        DOUBLE,
        number=7,
    )
    v7 = Field(
        DOUBLE,
        number=8,
    )


class Vector8List(Message):
    """Generated from ubii/proto/v1/dataStructure/vector8.proto

    Attributes:
        elements (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of
            type :obj:`~.Vector8`

    """

    elements = RepeatedField(
        Vector8,
        number=1,
    )

